# Generated by Django 4.2.11 on 2024-03-31 13:34

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('notificationcenter', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='notification',
            name='html',
        ),
        migrations.RemoveField(
            model_name='notification',
            name='link',
        ),
        migrations.RemoveField(
            model_name='notification',
            name='recipients',
        ),
        migrations.RemoveField(
            model_name='notification',
            name='subject',
        ),
        migrations.RemoveField(
            model_name='notification',
            name='text',
        ),
        migrations.AddField(
            model_name='notification',
            name='created_by',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
    ]
